using System;
using System.Text.Json.Serialization;
namespace org.accordproject.ciceromark {
   using org.accordproject.commonmark;
   using concerto;
   abstract class Element : Child {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "org.accordproject.ciceromark.Element";
      public string name { get; set; }
      public string elementType { get; set; }
   }
   class Variable : Element {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "org.accordproject.ciceromark.Variable";
      public string value { get; set; }
      public string identifiedBy { get; set; }
   }
   class FormattedVariable : Variable {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "org.accordproject.ciceromark.FormattedVariable";
      public string format { get; set; }
   }
   class EnumVariable : Variable {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "org.accordproject.ciceromark.EnumVariable";
      public string[] enumValues { get; set; }
   }
   class Formula : Element {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "org.accordproject.ciceromark.Formula";
      public string value { get; set; }
      public string[] dependencies { get; set; }
      public string code { get; set; }
   }
   abstract class Block : Element {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "org.accordproject.ciceromark.Block";
   }
   class Clause : Block {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "org.accordproject.ciceromark.Clause";
      public string src { get; set; }
   }
   class Conditional : Block {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "org.accordproject.ciceromark.Conditional";
      public bool isTrue { get; set; }
      public Child[] whenTrue { get; set; }
      public Child[] whenFalse { get; set; }
   }
   class Optional : Block {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "org.accordproject.ciceromark.Optional";
      public bool hasSome { get; set; }
      public Child[] whenSome { get; set; }
      public Child[] whenNone { get; set; }
   }
   class ListBlock : Block {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "org.accordproject.ciceromark.ListBlock";
      public string type { get; set; }
      public string tight { get; set; }
      public string start { get; set; }
      public string delimiter { get; set; }
   }
}
